Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1236)

Unified Diff: test/builddir/gyptest-all.py

Issue 12314014: CMake generator. (Closed) Base URL: http://gyp.googlecode.com/svn/trunk/
Patch Set: Address comments. Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « test/additional-targets/gyptest-additional.py ('k') | test/builddir/gyptest-default.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/builddir/gyptest-all.py
===================================================================
--- test/builddir/gyptest-all.py (revision 1794)
+++ test/builddir/gyptest-all.py (working copy)
@@ -23,9 +23,8 @@
# its sources. I'm not sure if make is wrong for writing outside the current
# directory, or if the test is wrong for assuming everything generated is under
# the current directory.
-# Android does not support setting the build directory.
-# Ninja does not support relocation.
-test = TestGyp.TestGyp(formats=['!make', '!ninja', '!android'])
+# Android, Ninja, and CMake do not support setting the build directory.
+test = TestGyp.TestGyp(formats=['!make', '!ninja', '!android', '!cmake'])
test.run_gyp('prog1.gyp', '--depth=..', chdir='src')
if test.format == 'msvs':
« no previous file with comments | « test/additional-targets/gyptest-additional.py ('k') | test/builddir/gyptest-default.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698